@@ -123,6 +123,7 @@ class AlbumArt:
             all_uris.append(f.get_uri())
         for uri in filter(lambda p: p.lower().endswith(self._MIMES), all_uris):
             return uri
+        infos.close(None)
         return None
 
     def get_album_artworks(self, album):
@@ -145,6 +146,7 @@ class AlbumArt:
             for uri in filter(lambda p: p.lower().endswith(self._MIMES),
                               all_uris):
                 uris.append(uri)
+            infos.close(None)
         except Exception as e:
             Logger.error("AlbumArt::get_album_artworks(): %s", e)
         return uris
@@ -197,7 +199,7 @@ class AlbumArt:
                     if uri is not None:
                         f = Gio.File.new_for_uri(uri)
                         (status, data, tag) = f.load_contents(None)
-                        bytes = GLib.Bytes(data)
+                        bytes = GLib.Bytes.new(data)
                         stream = Gio.MemoryInputStream.new_from_bytes(bytes)
                         pixbuf = GdkPixbuf.Pixbuf.new_from_stream(
                             stream, None)
@@ -221,7 +223,7 @@ class AlbumArt:
                     if uri is not None:
                         f = Gio.File.new_for_uri(uri)
                         (status, data, tag) = f.load_contents(None)
-                        bytes = GLib.Bytes(data)
+                        bytes = GLib.Bytes.new(data)
                         stream = Gio.MemoryInputStream.new_from_bytes(bytes)
                         pixbuf = GdkPixbuf.Pixbuf.new_from_stream(
                             stream, None)
@@ -337,7 +339,7 @@ class AlbumArt:
             if exist:
                 (exist, mapflags) = sample.get_buffer().map(Gst.MapFlags.READ)
             if exist:
-                bytes = GLib.Bytes(mapflags.data)
+                bytes = GLib.Bytes.new(mapflags.data)
                 stream = Gio.MemoryInputStream.new_from_bytes(bytes)
                 pixbuf = GdkPixbuf.Pixbuf.new_from_stream(stream, None)
                 stream.close()
@@ -458,7 +460,7 @@ class AlbumArt:
             @param album as Album
         """
         # https://bugzilla.gnome.org/show_bug.cgi?id=747431
-        bytes = GLib.Bytes(data)
+        bytes = GLib.Bytes.new(data)
         stream = Gio.MemoryInputStream.new_from_bytes(bytes)
         pixbuf = GdkPixbuf.Pixbuf.new_from_stream_at_scale(stream,
                                                            ArtSize.MPRIS,
