@@ -10,22 +10,58 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, GLib, Gio, Gdk
+from gi.repository import Gtk, GLib, Gio, Pango
 
 from gettext import gettext as _
 
-from lollypop.define import App, ArtSize, ViewType, MARGIN, MARGIN_SMALL
-from lollypop.objects import Album
-from lollypop.logger import Logger
-from lollypop.utils import escape
+from lollypop.define import App, ArtSize, ViewType, MARGIN, MARGIN_SMALL, Type
+from lollypop.objects_album import Album
 from lollypop.helper_art import ArtBehaviour
 from lollypop.information_store import InformationStore
 from lollypop.view_albums_list import AlbumsListView
-from lollypop.view import BaseView
-from lollypop.utils import on_realize
+from lollypop.view import View
+from lollypop.utils import set_cursor_type, get_network_available
+from lollypop.helper_gestures import GesturesHelper
 
 
-class InformationView(BaseView, Gtk.Bin):
+class ArtistRow(Gtk.ListBoxRow):
+    """
+        Artist row for Wikipedia
+    """
+
+    def __init__(self, item):
+        """
+            Init row
+            @param item as (str, str, str)
+        """
+        Gtk.ListBoxRow.__init__(self)
+        self.__locale = item[0]
+        self.__page_id = item[2]
+        label = Gtk.Label.new("%s: %s" % (item[0], item[1]))
+        label.set_property("halign", Gtk.Align.START)
+        label.set_ellipsize(Pango.EllipsizeMode.END)
+        label.get_style_context().add_class("padding")
+        label.show()
+        self.add(label)
+
+    @property
+    def locale(self):
+        """
+            Get locale
+            @return str
+        """
+        return self.__locale
+
+    @property
+    def page_id(self):
+        """
+            Get page id
+            @return str
+        """
+        return self.__page_id
+
+
+class InformationView(View):
     """
         View with artist information
     """
@@ -35,15 +71,13 @@ class InformationView(BaseView, Gtk.Bin):
             Init artist infos
             @param follow_player as bool
         """
-        BaseView.__init__(self)
-        Gtk.Bin.__init__(self)
+        View.__init__(self)
         self.__information_store = InformationStore()
         self.__information_store.connect("artist-info-changed",
                                          self.__on_artist_info_changed)
         self.__cancellable = Gio.Cancellable()
         self.__minimal = minimal
         self.__artist_name = ""
-        self.connect("unmap", self.__on_unmap)
 
     def populate(self, artist_id=None):
         """
@@ -58,29 +92,35 @@ class InformationView(BaseView, Gtk.Bin):
         widget = builder.get_object("widget")
         self.add(widget)
         self.__stack = builder.get_object("stack")
+        self.__listbox = builder.get_object("listbox")
         self.__artist_label = builder.get_object("artist_label")
-        self.__artist_label.connect("realize", on_realize)
         title_label = builder.get_object("title_label")
         self.__artist_artwork = builder.get_object("artist_artwork")
-        eventbox = builder.get_object("eventbox")
-        eventbox.connect("button-release-event",
-                         self.__on_label_button_release_event)
-        self.__information_label = builder.get_object("bio_label")
+        bio_eventbox = builder.get_object("bio_eventbox")
+        artist_label_eventbox = builder.get_object("artist_label_eventbox")
+        bio_eventbox.connect("realize", set_cursor_type)
+        artist_label_eventbox.connect("realize", set_cursor_type)
+        self.__gesture1 = GesturesHelper(
+            bio_eventbox,
+            primary_press_callback=self._on_info_label_press)
+        self.__gesture2 = GesturesHelper(
+            artist_label_eventbox,
+            primary_press_callback=self._on_artist_label_press)
+        self.__bio_label = builder.get_object("bio_label")
         if artist_id is None and App().player.current_track.id is not None:
             builder.get_object("header").show()
-            builder.get_object("lyrics_button").show()
-            builder.get_object("lyrics_button").connect(
-                "clicked",
-                self.__on_lyrics_button_clicked,
-                App().player.current_track)
-            artist_id = App().player.current_track.album.artist_ids[0]
+            if App().player.current_track.album.artist_ids[0] ==\
+                    Type.COMPILATIONS:
+                artist_id = App().player.current_track.artist_ids[0]
+            else:
+                artist_id = App().player.current_track.album.artist_ids[0]
             title_label.set_text(App().player.current_track.title)
         self.__artist_name = App().artists.get_name(artist_id)
         if self.__minimal:
-            self.__information_label.set_margin_start(MARGIN)
-            self.__information_label.set_margin_end(MARGIN)
-            self.__information_label.set_margin_top(MARGIN)
-            self.__information_label.set_margin_bottom(MARGIN)
+            self.__bio_label.set_margin_start(MARGIN)
+            self.__bio_label.set_margin_end(MARGIN)
+            self.__bio_label.set_margin_top(MARGIN)
+            self.__bio_label.set_margin_bottom(MARGIN)
             self.__artist_artwork.hide()
         else:
             self.__artist_artwork.set_margin_start(MARGIN_SMALL)
@@ -90,14 +130,15 @@ class InformationView(BaseView, Gtk.Bin):
             title_label.show()
             App().art_helper.set_artist_artwork(
                                     self.__artist_name,
-                                    ArtSize.ARTIST_SMALL * 3,
-                                    ArtSize.ARTIST_SMALL * 3,
+                                    ArtSize.SMALL * 3,
+                                    ArtSize.SMALL * 3,
                                     self.__artist_artwork.get_scale_factor(),
                                     ArtBehaviour.ROUNDED |
                                     ArtBehaviour.CROP_SQUARE |
                                     ArtBehaviour.CACHE,
                                     self.__on_artist_artwork)
-            albums_view = AlbumsListView([], [], ViewType.POPOVER)
+            albums_view = AlbumsListView([], [],
+                                         ViewType.SCROLLED | ViewType.ALBUM)
             albums_view.set_size_request(300, -1)
             albums_view.show()
             albums_view.set_margin_start(5)
@@ -116,14 +157,63 @@ class InformationView(BaseView, Gtk.Bin):
 #######################
 # PROTECTED           #
 #######################
-    def _on_label_realize(self, eventbox):
+    def _on_unmap(self, widget):
         """
-            @param eventbox as Gtk.EventBox
+            Cancel operations
+            @param widget as Gtk.Widget
         """
-        try:
-            eventbox.get_window().set_cursor(Gdk.Cursor(Gdk.CursorType.HAND2))
-        except:
-            Logger.warning(_("You are using a broken cursor theme!"))
+        self.__cancellable.cancel()
+
+    def _on_previous_button_clicked(self, button):
+        """
+            Go back to main view
+            @param button as Gtk.Button
+        """
+        self.__stack.set_visible_child_name("main")
+
+    def _on_artist_label_press(self, x, y, event):
+        """
+            Go to artist view
+            @param x as int
+            @param y as int
+            @param event as Gdk.Event
+        """
+        popover = self.get_ancestor(Gtk.Popover)
+        if popover is not None:
+            popover.popdown()
+        if App().player.current_track.id is None:
+            return
+        GLib.idle_add(App().window.container.show_view,
+                      [Type.ARTISTS],
+                      App().player.current_track.album.artist_ids)
+
+    def _on_info_label_press(self, x, y, event):
+        """
+            Show information cache (for edition)
+            @param x as int
+            @param y as int
+            @param event as Gdk.Event
+        """
+        if get_network_available("WIKIPEDIA"):
+            from lollypop.wikipedia import Wikipedia
+            wikipedia = Wikipedia()
+            self.__stack.set_visible_child_name("select")
+            App().task_helper.run(wikipedia.get_search_list,
+                                  self.__artist_name,
+                                  callback=(self.__on_wikipedia_search_list,))
+
+    def _on_row_activated(self, listbox, row):
+        """
+            Update artist information
+            @param listbox as Gtk.ListBox
+            @param row as Gtk.ListBoxRow
+        """
+        self.__stack.set_visible_child_name("main")
+        from lollypop.wikipedia import Wikipedia
+        wikipedia = Wikipedia()
+        App().task_helper.run(wikipedia.get_content_for_page_id,
+                              row.page_id, row.locale,
+                              callback=(self.__on_wikipedia_get_content,))
 
 #######################
 # PRIVATE             #
@@ -135,13 +225,13 @@ class InformationView(BaseView, Gtk.Bin):
             @param initial as bool => initial loading
         """
         if content:
-            self.__information_label.set_markup(
+            self.__bio_label.set_markup(
                 GLib.markup_escape_text(content.decode("utf-8")))
         elif initial:
-            self.__information_label.set_text(_("Loading information"))
+            self.__bio_label.set_text(_("Loading information"))
             self.__information_store.cache_artist_info(self.__artist_name)
         else:
-            self.__information_label.set_text(
+            self.__bio_label.set_text(
                 _("No information for %s") % self.__artist_name)
 
     def __get_artist_artwork_path_from_cache(self, artist, size):
@@ -157,53 +247,25 @@ class InformationView(BaseView, Gtk.Bin):
             return path
         return None
 
-    def __on_lyrics_button_clicked(self, button, track):
+    def __on_wikipedia_search_list(self, items):
         """
-            Show lyrics
-            @param button as Gtk.Button
-            @param track as Track
+            Populate view with items
+            @param items as [(str, str)]
         """
-        popover = self.get_ancestor(Gtk.Popover)
-        if popover is not None:
-            popover.popdown()
-        App().window.container.show_lyrics(track)
+        for item in items:
+            row = ArtistRow(item)
+            row.show()
+            self.__listbox.add(row)
 
-    def _on_artist_button_release_event(self, eventbox, event):
+    def __on_wikipedia_get_content(self, content):
         """
-            Go to artist view
-            @param eventbox as Gtk.EventBox
-            @param event as Gdk.Event
+            Update label and save to cache
+            @param content as str
         """
-        popover = self.get_ancestor(Gtk.Popover)
-        if popover is not None:
-            popover.popdown()
-        if App().player.current_track.id is None:
-            return
-        GLib.idle_add(App().window.container.show_artists_albums,
-                      App().player.current_track.album.artist_ids)
-
-    def __on_label_button_release_event(self, button, event):
-        """
-            Show information cache (for edition)
-            @param button as Gtk.Button
-            @param event as Gdk.Event
-        """
-        uri = "file://%s/%s.txt" % (App().art._INFO_PATH,
-                                    escape(self.__artist_name))
-        f = Gio.File.new_for_uri(uri)
-        if not f.query_exists():
-            f.replace_contents(b"", None, False,
-                               Gio.FileCreateFlags.NONE, None)
-        Gtk.show_uri_on_window(App().window,
-                               uri,
-                               Gdk.CURRENT_TIME)
-
-    def __on_unmap(self, widget):
-        """
-            Cancel operations
-            @param widget as Gtk.Widget
-        """
-        self.__cancellable.cancel()
+        if content is not None:
+            self.__bio_label.set_text(content.decode("utf-8"))
+            self.__information_store.save_artist_information(
+                self.__artist_name, content)
 
     def __on_artist_artwork(self, surface):
         """
