@@ -12,7 +12,7 @@
 
 from gi.repository import Gtk, Gdk, GObject
 
-from lollypop.define import ArtSize, ViewType, MARGIN, App
+from lollypop.define import ArtSize, ViewType, MARGIN, App, Size
 from lollypop.utils import emit_signal
 from lollypop.helper_size_allocation import SizeAllocationHelper
 
@@ -21,13 +21,12 @@ class Overlay(Gtk.Overlay):
     """
         Overlay with constraint size
     """
-    def __init__(self, banner):
+    def __init__(self):
         """
             Init overlay
             @param banner as BannerWidget
         """
         Gtk.Overlay.__init__(self)
-        self.__banner = banner
 
     def do_get_preferred_width(self):
         """
@@ -35,14 +34,7 @@ class Overlay(Gtk.Overlay):
         """
         (min, nat) = Gtk.Bin.do_get_preferred_width(self)
         # Allow resizing
-        return (0, 0)
-
-    def do_get_preferred_height(self):
-        """
-           Force preferred height
-        """
-        height = self.__banner.height
-        return (height, height)
+        return (1, 1)
 
 
 class BannerWidget(Gtk.Revealer, SizeAllocationHelper):
@@ -51,7 +43,8 @@ class BannerWidget(Gtk.Revealer, SizeAllocationHelper):
     """
 
     gsignals = {
-        "scroll": (GObject.SignalFlags.RUN_FIRST, None, (float, float))
+        "scroll": (GObject.SignalFlags.RUN_FIRST, None, (float, float)),
+        "height-changed": (GObject.SignalFlags.RUN_FIRST, None, (int,)),
     }
     for signal in gsignals:
         args = gsignals[signal]
@@ -64,15 +57,17 @@ class BannerWidget(Gtk.Revealer, SizeAllocationHelper):
             @param view_type as ViewType
         """
         Gtk.Revealer.__init__(self)
+        self._artwork = None
         self._view_type = view_type
+        self.__width = 1
         self.set_property("valign", Gtk.Align.START)
         if view_type & ViewType.OVERLAY:
-            self._overlay = Overlay(self)
+            self._overlay = Overlay()
             self._overlay.show()
             self._artwork = Gtk.Image()
             self._artwork.show()
+            SizeAllocationHelper.__init__(self)
             if App().animations:
-                SizeAllocationHelper.__init__(self)
                 self._artwork.set_opacity(0.99)
             self.get_style_context().add_class("default-banner")
             self._artwork.get_style_context().add_class("default-banner")
@@ -89,13 +84,31 @@ class BannerWidget(Gtk.Revealer, SizeAllocationHelper):
             self.add(self._overlay)
         self.set_reveal_child(True)
         self.set_transition_duration(250)
+        self.connect("destroy", self.__on_destroy)
 
-    def set_view_type(self, view_type):
+    def update_for_width(self, width):
         """
-            Update widget internals for view_type
-            @param view_type as ViewType
+            Update banner internals for width, call this before showing banner
+            @param width as int
         """
-        self._view_type = view_type
+        self.__width = width
+        self._artwork.set_size_request(-1, self.height)
+
+    @property
+    def width(self):
+        """
+            Get current width
+            @return int
+        """
+        # If not SMALL, we add sidebar width because we want banners
+        # to calculate sizing with sidebar included. Allows to prevent
+        # glitch when sidebar is auto shown
+        if not App().window.is_adaptive:
+            sidebar_width = App().window.container.sidebar.\
+                get_allocated_width()
+            return self.__width + sidebar_width
+        else:
+            return self.__width
 
     @property
     def height(self):
@@ -103,14 +116,32 @@ class BannerWidget(Gtk.Revealer, SizeAllocationHelper):
             Get wanted height
             @return int
         """
-        if self._view_type & (ViewType.ADAPTIVE | ViewType.SMALL):
-            return ArtSize.MEDIUM + MARGIN * 2
+        if self.width <= Size.SMALL:
+            height = ArtSize.MEDIUM
+        elif self.width <= Size.MEDIUM:
+            height = ArtSize.MEDIUM + MARGIN * 2
         else:
-            return ArtSize.BANNER + MARGIN * 2
+            height = ArtSize.BANNER + MARGIN * 2
+        return height
 
 #######################
 # PROTECTED           #
 #######################
+    def _handle_width_allocate(self, allocation):
+        """
+            Update artwork
+            @param allocation as Gtk.Allocation
+            @return bool
+        """
+        if SizeAllocationHelper._handle_width_allocate(self, allocation):
+            if allocation.width != self.__width:
+                self.__width = allocation.width
+                height = self.height
+                self._artwork.set_size_request(-1, height)
+                emit_signal(self, "height-changed", height)
+                return True
+        return False
+
     def _on_artwork(self, surface):
         """
             Set album artwork
@@ -131,6 +162,13 @@ class BannerWidget(Gtk.Revealer, SizeAllocationHelper):
 #######################
 # PRIVATE             #
 #######################
+    def __on_destroy(self, widget):
+        """
+            Remove ref cycle
+            @param widget as Gtk.Widget
+        """
+        self.__event_controller = None
+
     def __on_scroll(self, event_controller, x, y):
         """
             Pass scroll
